@@ -77,17 +77,35 @@ sub _run {
 }
 
 sub status {
-    my $class = shift;
+    my ($class,$args) = @_;
+    $args //= {};
+    my $self = $class->new($args);
 
     # Check if main handler initialization has been done
     unless (%$tsv) {
-        eval { $class->subhandler->checkConf() };
-        $class->lmLog( $@, 'error' ) if ($@);
+        return $self->abort( $self->error ) unless ( $self->init($args) );
     }
     return sub {
         my $req = Lemonldap::NG::Common::PSGI::Request->new( $_[0] );
         Lemonldap::NG::Handler::API->newRequest($req);
-        $class->subhandler->status();
+        $self->subhandler->status();
+        return [ 200, [ %{ $req->{respHeaders} } ], [ $req->{respBody} ] ];
+    };
+}
+
+sub reload {
+    my ($class,$args) = @_;
+    $args //= {};
+    my $self = $class->new($args);
+
+    # Check if main handler initialization has been done
+    unless (%$tsv) {
+        return $self->abort( $self->error ) unless ( $self->init($args) );
+    }
+    return sub {
+        my $req = Lemonldap::NG::Common::PSGI::Request->new( $_[0] );
+        Lemonldap::NG::Handler::API->newRequest($req);
+        $self->subhandler->reload();
         return [ 200, [ %{ $req->{respHeaders} } ], [ $req->{respBody} ] ];
     };
 }
